@@ -81,6 +81,10 @@ class Subscription(Base):
     def webhook_url(self):
         return self._get_property('webhookUrl')
 
+    @property
+    def metadata(self):
+        return self._get_property('metadata')
+
     @property
     def customer(self):
         """Return the customer for this subscription."""
