@@ -15,7 +15,7 @@ class Payments(Base):
                 "Invalid payment ID: '{id}'. A payment ID should start with '{prefix}'.".format(
                     id=payment_id, prefix=self.RESOURCE_ID_PREFIX)
             )
-        return super(Payments, self).get(payment_id, **params)
+        return super().get(payment_id, **params)
 
     def delete(self, payment_id, data=None):
         """Cancel payment and return the payment object.
@@ -28,5 +28,5 @@ class Payments(Base):
                 "Invalid payment ID: '{id}'. A payment ID should start with '{prefix}'.".format(
                     id=payment_id, prefix=self.RESOURCE_ID_PREFIX)
             )
-        result = super(Payments, self).delete(payment_id, data)
+        result = super().delete(payment_id, data)
         return self.get_resource_object(result)
